@@ -20,7 +20,7 @@
 
 from customWidgets import SelectableBoxesArea
 from dataHolder import DataBox, PageData, TEXT_TYPE, IMAGE_TYPE
-from ocrfeeder.feeder.documentGeneration import OdtGenerator, HtmlGenerator
+from ocrfeeder.feeder.documentGeneration import OdtGenerator, HtmlGenerator, PlaintextGenerator
 from ocrfeeder.feeder.imageManipulation import *
 from ocrfeeder.feeder.layoutAnalysis import *
 from pango import FontDescription, SCALE
@@ -304,23 +304,35 @@ class ImageReviewer:
                 editor.box_editor.setText('')
         self.updateMainWindow()
 
-    def copyTextToClipboard(self):
+    def getTextFromBoxes(self, boxes):
         text = ''
-        selected_boxes = self.selectable_boxes_area.getSelectedAreas()
-        selected_boxes.reverse()
-        if selected_boxes:
-            number_of_boxes = len(selected_boxes)
+        boxes.reverse()
+        if boxes:
+            number_of_boxes = len(boxes)
             for i in range(number_of_boxes):
-                box = selected_boxes[i]
-                text += self.__getEditorFromBox(box).box_editor.getText()
+                box = boxes[i]
+                box_editor = self.__getEditorFromBox(box).box_editor
+                if box_editor.getType() != TEXT_TYPE:
+                    continue
+                text += box_editor.getText()
                 if number_of_boxes > 1 and i < number_of_boxes - 1:
                     text += '\n\n'
         else:
             current_box_editor = self.boxeditor_notebook.get_nth_page(\
                                      self.boxeditor_notebook.get_current_page())
-            text = current_box_editor.getText()
+            if current_box_editor.getType() == TEXT_TYPE:
+                text = current_box_editor.getText()
+        return text
+
+    def copyTextToClipboard(self):
+        selected_boxes = self.selectable_boxes_area.getSelectedAreas()
+        text = self.getTextFromBoxes(selected_boxes)
         gtk.Clipboard().set_text(text)
 
+    def getAllText(self):
+        boxes = self.selectable_boxes_area.getAllAreas()
+        return self.getTextFromBoxes(boxes)
+
     def __getAllDataBoxes(self):
         boxes = []
         for editor in self.editor_list:
@@ -409,8 +421,10 @@ class ImageReviewer_Controler:
         self.source_images_selector_widget = source_images_selector_widget
         self.ocr_engines = ocr_engines
         self.configuration_manager = configuration_manager
-        self.tripple_statusbar = self.main_window.tripple_statusbar
+        self.statusbar = self.main_window.statusbar
+        self._page_info_message_id = self.statusbar.get_context_id('page_info_message')
         self.source_images_selector_widget.connect(selection_changed_signal, self.selectImageReviewer)
+        self.__updateStatusBar()
 
     def __createdImageReviewer(self, pixbuf, image):
         image_reviewer = ImageReviewer(self.main_window, image, self.ocr_engines)
@@ -440,12 +454,12 @@ class ImageReviewer_Controler:
                               index == item_list_length - 1,
                               index == 0))
             if item_list_length == 1:
-                item_info = (_('Preparing image'), _('Please wait…'))
+                item_info = (_('Preparing image'), _(u'Please wait…'))
             else:
                 item_info = (_('Preparing image %(current_index)s/%(total)s') % \
                              {'current_index': index + 1,
                               'total': item_list_length},
-                             _('Please wait…'))
+                             _(u'Please wait…'))
             item_list.append((item_info,item))
         dialog.setItemsList(item_list)
         dialog.run()
@@ -497,7 +511,7 @@ class ImageReviewer_Controler:
                          (reviewer.path_to_image,),
                          self.__deskewCurrentImageFinishedCb,
                          (dialog, reviewer))
-        item_info = (_('Deskewing image'), _('Please wait…'))
+        item_info = (_('Deskewing image'), _(u'Please wait…'))
         dialog.setItemsList([(item_info, item)])
         dialog.run()
 
@@ -514,28 +528,83 @@ class ImageReviewer_Controler:
             reviewer = self.image_reviewer_dict[pixbuf]
             self.notebook.set_current_page(self.notebook.page_num(reviewer.reviewer_area))
             self.__setZoomStatus(None, reviewer.selectable_boxes_area.get_scale())
-            self.tripple_statusbar.center_statusbar.insert((_('Page size') + ': %.2f x %.2f') % (reviewer.getPageData().width, reviewer.getPageData().height))
-            self.tripple_statusbar.right_statusbar.insert((_('Resolution') + ': %i x %i') % (reviewer.getPageData().resolution[0], reviewer.getPageData().resolution[1]))
+            self.__updateStatusBar(reviewer)
             reviewer.updateMainWindow()
 
     def __setZoomStatus(self, widget, zoom):
-        self.tripple_statusbar.left_statusbar.insert(_('Zoom') + ': ' + str(int(zoom * 100)) + '%')
+        self.__updateStatusBar()
+
+    def __updateStatusBar(self, reviewer = None):
+        reviewer = reviewer or self.__getCurrentReviewer()
+
+        if not reviewer:
+            status_message = _('No images added')
+        else:
+            zoom = int(reviewer.selectable_boxes_area.get_scale() * 100)
+            status_message = _('Zoom: %s %%') % zoom
+            page_data = reviewer.getPageData()
+            status_message += ' ' + _('Resolution: %.2f x %.2f') % (page_data.resolution[0],
+                                                                    page_data.resolution[1])
+            status_message += ' ' + _('Page size: %i x %i') % (page_data.width,
+                                                               page_data.height)
+
+        self.statusbar.pop(self._page_info_message_id)
+        self.statusbar.push(self._page_info_message_id, status_message)
 
     def recognizeSelectedAreas(self, widget):
         image_reviewer = self.__getCurrentReviewer()
         image_reviewer.performOcrForSelectedBoxes(self.configuration_manager.favorite_engine)
 
+    def __confirmOveritePossibilityByRecognition(self):
+        confirm_recognition = gtk.MessageDialog(parent = self.main_window.window,
+                                                type = gtk.MESSAGE_QUESTION,
+                                                buttons = gtk.BUTTONS_YES_NO)
+        message = _('There are changes that may be overwritten '
+                    'by the new recognition.\n\n'
+                    'Do you want to continue?')
+        confirm_recognition.set_markup(message)
+        response = confirm_recognition.run()
+        confirm_recognition.destroy()
+        return response
+
     def recognizeCurrentPage(self):
         image_reviewer = self.__getCurrentReviewer()
+        if image_reviewer.selectable_boxes_area.getAllAreas() and \
+           self.__confirmOveritePossibilityByRecognition() != gtk.RESPONSE_YES:
+                return
         dialog = QueuedEventsProgressDialog(self.main_window.window)
         item = AsyncItem(self.__performRecognitionForReviewer,
                          (image_reviewer,),
                          self.__performRecognitionForReviewerFinishedCb,
-                         (dialog, image_reviewer,))
-        info = (_('Recognizing Document'), _('Please wait…'))
+                         (dialog, image_reviewer, [image_reviewer]))
+        info = (_('Recognizing Page'), _(u'Please wait…'))
         dialog.setItemsList([(info, item)])
         dialog.run()
 
+    def recognizeDocument(self):
+        reviewers = self.image_reviewer_dict.values()
+        dialog = QueuedEventsProgressDialog(self.main_window.window)
+        items = []
+        i = 1
+        total = len(reviewers)
+        has_changes = False
+        for reviewer in reviewers:
+            has_changes = has_changes or bool(reviewer.selectable_boxes_area.getAllAreas())
+            item = AsyncItem(self.__performRecognitionForReviewer,
+                             (reviewer,),
+                             self.__performRecognitionForReviewerFinishedCb,
+                             (dialog, reviewer, reviewers))
+            info = (_('Recognizing Document'),
+                    _(u'Recognizing page %(page_number)s/%(total_pages)s. Please wait…') % {'page_number': i,
+                                                                                            'total_pages': total})
+            items.append((info, item))
+            i += 1
+        if has_changes and \
+           self.__confirmOveritePossibilityByRecognition() != gtk.RESPONSE_YES:
+                return
+        dialog.setItemsList(items)
+        dialog.run()
+
     def __performRecognitionForReviewer(self, image_reviewer):
         window_size = self.configuration_manager.window_size
         if window_size == 'auto':
@@ -571,13 +640,16 @@ class ImageReviewer_Controler:
         return None
 
     def __performRecognitionForReviewerFinishedCb(self, dialog, image_reviewer,
+                                                  reviewers_to_process,
                                                   data_boxes, error):
         image_reviewer.clear()
         image_reviewer.applyTextColors()
         for data_box in data_boxes:
             image_reviewer.addDataBox(data_box)
-        dialog.cancel()
-        image_reviewer.updateMainWindow()
+        if image_reviewer == reviewers_to_process[-1]:
+            dialog.cancel()
+            for reviewer in reviewers_to_process:
+                reviewer.updateMainWindow()
 
     def copyRecognizedTextToClipboard(self, widget):
         image_reviewer = self.__getCurrentReviewer()
@@ -615,6 +687,17 @@ class ImageReviewer_Controler:
                 document_generator.addPage(image_reviewer.getPageData())
             document_generator.save()
 
+    def exportPagesToPlaintext(self, pixbufs_sorted = []):
+        image_reviewers = self.__askForNumberOfPages(_('Export to Plain Text'), pixbufs_sorted)
+        if not image_reviewers:
+            return
+        file_name = self.__askForFileName()
+        if file_name:
+            document_generator = PlaintextGenerator(file_name)
+            for image_reviewer in image_reviewers:
+                document_generator.addText(image_reviewer.getAllText())
+            document_generator.save()
+
     def saveProjectAs(self):
         return self.__askForFileName(extension = '.ocrf')
 
@@ -729,7 +812,8 @@ class ImageReviewer_Controler:
             if image_reviewer == current_reviewer:
                 del self.image_reviewer_dict[pixbuf]
                 self.notebook.remove_page(self.notebook.get_current_page())
-                return True
+                break
+        self.__updateStatusBar()
 
     def unpaperTool(self):
         current_reviewer = self.__getCurrentReviewer()
@@ -746,7 +830,7 @@ class ImageReviewer_Controler:
             del self.image_reviewer_dict[pixbuf]
             self.notebook.remove_page(self.notebook.get_current_page())
         self.source_images_selector_widget.clear()
-        self.tripple_statusbar.clear()
+        self.__updateStatusBar()
 
     def getPixbufsSorted(self):
         return self.source_images_selector_widget.source_images_selector.getPixbufsSorted()
