@@ -18,7 +18,7 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ###########################################################################
 
-from customWidgets import PlainFrame, TrippleStatusBar
+from customWidgets import PlainFrame, PlainExpander
 from dataHolder import DataBox, TEXT_TYPE, IMAGE_TYPE
 from configuration import ConfigurationManager
 from ocrfeeder.util import lib, PAPER_SIZES
@@ -81,7 +81,8 @@ class MainWindow:
             <menuitem action="ZoomFit"/>
         </menu>
         <menu action="Document">
-            <menuitem action="OCRFeederDetection"/>
+            <menuitem action="OCRFeederReconDocument"/>
+            <menuitem action="OCRFeederReconPage"/>
             <menuitem action="RecognizeAreas"/>
             <menuitem action="SelectAllAreas"/>
             <menuitem action="SelectPreviousArea"/>
@@ -104,7 +105,7 @@ class MainWindow:
     <toolbar name="ToolBar">
         <toolitem action="AddImage"/>
         <separator/>
-        <toolitem action="OCRFeederDetection"/>
+        <toolitem action="OCRFeederReconDocument"/>
         <toolitem action="GenerateODT"/>
         <separator/>
         <toolitem action="ZoomOut"/>
@@ -119,8 +120,9 @@ class MainWindow:
         self.main_box = gtk.VBox()
         self.main_box.show()
 
-        self.tripple_statusbar = TrippleStatusBar()
-        self.main_box.pack_end(self.tripple_statusbar, False)
+        self.statusbar = gtk.Statusbar()
+        self.statusbar.show()
+        self.main_box.pack_end(self.statusbar, False)
 
         self.main_area = gtk.HPaned()
         self.main_area.set_position(150)
@@ -154,12 +156,12 @@ class MainWindow:
                                   ('Quit', gtk.STOCK_QUIT, _('_Quit'), None, _('Exit the program'), menu_items['exit']),
                                   ('OpenProject', gtk.STOCK_OPEN, _('_Open'), None, _('Open project'), menu_items['open_project']),
                                   ('SaveProject', gtk.STOCK_SAVE, _('_Save'), None, _('Save project'), menu_items['save_project']),
-                                  ('SaveProjectAs', gtk.STOCK_SAVE_AS, _('_Save As…'), '<control><shift>s', _('Save project with a chosen name'), menu_items['save_project_as']),
+                                  ('SaveProjectAs', gtk.STOCK_SAVE_AS, _(u'_Save As…'), '<control><shift>s', _('Save project with a chosen name'), menu_items['save_project_as']),
                                   ('AddImage', gtk.STOCK_ADD, _('_Add Image'), None, _('Add another image'), menu_items['add_image']),
                                   ('AddFolder', gtk.STOCK_ADD, _('Add _Folder'), None, _('Add all images in a folder'), menu_items['add_folder']),
                                   ('AppendProject', gtk.STOCK_ADD, _('Append Project'), None, _('Load a project and append it to the current one'), menu_items['append_project']),
                                   ('ImportPDF', gtk.STOCK_ADD, _('_Import PDF'), None, _('Import PDF'), menu_items['import_pdf']),
-                                  ('Export', None, _('_Export…'), '<control><shift>e', _('Export to a chosen format'), menu_items['export_dialog']),
+                                  ('Export', None, _(u'_Export…'), '<control><shift>e', _('Export to a chosen format'), menu_items['export_dialog']),
                                   ('Edit', None, _('_Edit')),
                                   ('EditPage', gtk.STOCK_EDIT, _('_Edit Page'), None, _('Edit page settings'), menu_items['edit_page']),
                                   ('Preferences', gtk.STOCK_PREFERENCES, _('_Preferences'), None, _('Configure the application'), menu_items['preferences']),
@@ -180,8 +182,18 @@ class MainWindow:
                                   ('Help', None, _('_Help')),
                                   ('HelpContents', gtk.STOCK_HELP, _('_Help'), 'F1', _('Help contents'), menu_items['help_contents']),
                                   ('About', gtk.STOCK_ABOUT, _('_About'), None, _('About this application'), menu_items['about']),
-                                  ('OCRFeederDetection', None, _('_Recognize Document'), None, _("Automatic Detection and Recognition"), tool_items['detection']),
-                                  ('RecognizeAreas', None, _('Recognize Selected _Areas'), None, _("Recognize Selected Areas"), menu_items['recognize_areas']),
+                                  ('OCRFeederReconDocument', None,
+                                   _('_Recognize Document'), '<control><shift>d',
+                                   _("Automatically detect and recognize all pages"),
+                                   tool_items['recognizeDocument']),
+                                  ('OCRFeederReconPage', None,
+                                   _('_Recognize Page'), '<control><shift>g',
+                                   _("Automatically detect and recognize the current page"),
+                                   tool_items['recognizePage']),
+                                  ('RecognizeAreas', None,
+                                   _('Recognize Selected _Areas'), '<control><shift>r',
+                                   _("Recognize Selected Areas"),
+                                   menu_items['recognize_areas']),
                                   ('SelectAllAreas', None,
                                    _('Select All _Areas'), '<control><shift>a',
                                    _("Select all content areas"),
@@ -211,7 +223,7 @@ class MainWindow:
                                    menu_items['copy_to_clipboard']),
                                   ('SpellChecker', None,
                                    _('Spell_checker'),
-                                   '<control><shift>r',
+                                   '<shift>F7',
                                    _("Spell Check Recognized Text"),
                                    menu_items['spell_checker']),
                                   ])
@@ -224,7 +236,7 @@ class MainWindow:
         self.main_box.pack_start(tool_bar, False, False)
         odt_export_button = ui_manager.get_widget('/ToolBar/GenerateODT')
         odt_export_button.set_icon_name('ooo-writer')
-        detection_button = ui_manager.get_widget('/ToolBar/OCRFeederDetection')
+        detection_button = ui_manager.get_widget('/ToolBar/OCRFeederReconDocument')
         detection_icon = gtk.image_new_from_file(DETECT_ICON)
         detection_icon.show()
         detection_button.set_icon_widget(detection_icon)
@@ -249,9 +261,9 @@ class MainWindow:
         if not self.action_group:
             return
         actions = ['ZoomIn', 'ZoomOut', 'ResetZoom',
-                   'Export', 'GenerateODT', 'Unpaper',
+                   'Export', 'GenerateODT', 'Unpaper', 'OCRFeederReconPage',
                    'DeletePage', 'SaveProject', 'SaveProjectAs',
-                   'OCRFeederDetection', 'EditPage', 'ClearProject',
+                   'OCRFeederReconDocument', 'EditPage', 'ClearProject',
                    'AppendProject', 'ZoomFit', 'ImageDeskewer']
         self.__setActionsSensitiveness(actions, has_images)
         if not has_images:
@@ -406,7 +418,7 @@ class BoxEditor(gtk.ScrolledWindow, gobject.GObject):
                 height == self.height_spin_button.get_value()
 
     def __makeBoundsProperties(self):
-        dimensions_frame = PlainFrame(_('Bounds'))
+        dimensions_frame = PlainExpander(_('Bounds'))
         box = gtk.VBox(True, 0)
         row = gtk.HBox(False, 12)
         size_group = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
@@ -515,7 +527,10 @@ class BoxEditor(gtk.ScrolledWindow, gobject.GObject):
         text_properties_notebook.set_tab_pos(gtk.POS_TOP)
         # Textview widget
         self.text_widget = gtk.TextView()
-        gtkspell.Spell(self.text_widget, OCRFEEDER_DEFAULT_LOCALE)
+        try:
+            gtkspell.Spell(self.text_widget, OCRFEEDER_DEFAULT_LOCALE)
+        except:
+            pass # The locale was not found by GTKSpell, ignoring...
         self.text_widget.set_wrap_mode(gtk.WRAP_WORD)
         self.text_content = self.text_widget.get_buffer()
         self.text_content.connect('changed', self.editedByUser)
@@ -749,7 +764,7 @@ class ExportDialog(gtk.Dialog):
         self.vbox.add(page_selection_frame)
 
     def getSelectedFormat(self):
-        return self.format_combo.get_active_text()
+        return self.format_combo.get_active()
 
 class PageSizeDialog(gtk.Dialog):
 
@@ -766,7 +781,7 @@ class PageSizeDialog(gtk.Dialog):
         self.paper_sizes = gtk.combo_box_new_text()
         papers = PAPER_SIZES.keys()
         papers.sort()
-        self.paper_sizes.append_text(_('Custom…'))
+        self.paper_sizes.append_text(_(u'Custom…'))
         for paper in papers:
             self.paper_sizes.append_text(paper)
         active_index = self.__checkIfSizeIsStandard(page_size)
@@ -900,7 +915,7 @@ class UnpaperDialog(gtk.Dialog):
         if os.path.exists(unpapered_image):
             unpapered_image = lib.getNonExistingFileName(unpapered_image)
         command += ' %s %s' % (name, unpapered_image)
-        progress_bar = CommandProgressBarDialog(command, _('Performing Unpaper'), _('Performing unpaper. Please wait…'))
+        progress_bar = CommandProgressBarDialog(command, _('Performing Unpaper'), _(u'Performing unpaper. Please wait…'))
         progress_bar.run()
         self.unpapered_image = unpapered_image
 
@@ -1282,8 +1297,9 @@ class PreferencesDialog(gtk.Dialog):
             self.__getBoundsAdjustmentSize()
         self.configuration_manager.deskew_images_after_addition = \
             self.deskew_images.get_active()
-        self.configuration_manager.unpaper_images_after_addition = \
-            self.unpaper_images.get_active()
+        if self.configuration_manager.has_unpaper:
+            self.configuration_manager.unpaper_images_after_addition = \
+                self.unpaper_images.get_active()
         index = self.engines_combo.get_active()
         if index != -1:
             lib.debug('ACTIVE INDEX: ', index, self.ocr_engines[index][0].name)
@@ -1751,10 +1767,12 @@ class OcrManagerDialog(gtk.Dialog):
     def __detectEnginesCb(self, button):
         engines = self.engines_manager.configuration_manager.getEnginesInSystem()
         if not engines:
-            info = InfoDialog(_('No OCR engines were found in the system.\n'
-                                'Please make sure you have OCR engines installed '
-                                'and available.'),
-                              _('No OCR engines available'))
+            info = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO,
+                                     gtk.BUTTONS_OK)
+            info.set_title(_('No OCR engines available'))
+            info.set_markup(_('No OCR engines were found in the system.\n'
+                              'Please make sure you have OCR engines installed '
+                              'and available.'))
             info.run()
             info.destroy()
             return
